@@ -1,4 +1,4 @@
-/* filelib.c - jonclegg@yahoo.com
+/* filelib.c
  * library routines for file operations
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,7 +15,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -53,9 +52,6 @@ static BOOL file_exists (char *filename);
 static void trim_filename (char *filename, char* out);
 static void trim_mp3_suffix (char *filename);
 static error_code filelib_open_for_write (FHANDLE* fp, char *filename);
-#if defined (commentout)
-static int is_absolute_path (char* fn);
-#endif
 static void
 parse_and_subst_dir (char* pattern_head, char* pattern_tail, char* opat_path,
 		     int is_for_showfile);
@@ -93,6 +89,7 @@ static FHANDLE  m_cue_file;
 static int 	m_count;
 static int      m_do_show;
 static char 	m_default_pattern[SR_MAX_PATH];
+static char 	m_default_showfile_pattern[SR_MAX_PATH];
 static char 	m_output_directory[SR_MAX_PATH];
 static char 	m_output_pattern[SR_MAX_PATH];
 static char 	m_incomplete_directory[SR_MAX_PATH];
@@ -224,6 +221,7 @@ filelib_init (BOOL do_individual_tracks,
 
     sprintf (m_incomplete_directory, "%s%s%c", m_output_directory,
 	     "incomplete", PATH_SLASH);
+    debug_printf ("Incomplete directory: %s\n", m_incomplete_directory);
 
     /* Recursively make the output directory & incomplete directory */
     if (m_do_individual_tracks) {
@@ -252,7 +250,7 @@ filelib_init (BOOL do_individual_tracks,
 			      m_showfile_pattern,
 			      showfile_pattern,
 			      output_directory,
-			      "%S/sr_program_%d",
+			      m_default_showfile_pattern,
 			      "",
 			      get_separate_dirs,
 			      get_date_stamp,
@@ -264,11 +262,13 @@ filelib_init (BOOL do_individual_tracks,
     return SR_SUCCESS;
 }
 
-/* This sets the value for m_default_pattern, using the -q & -s flags */
+/* This sets the value for m_default_pattern and m_default_showfile_pattern,
+   using the -q & -s flags.  This function cannot overflow 
+   these static buffers. */
 static void
 set_default_pattern (BOOL get_separate_dirs, BOOL do_count)
 {
-    /* None of these operations can overflow m_default_pattern */
+    /* m_default_pattern */
     m_default_pattern[0] = '\0';
     if (get_separate_dirs) {
 	strcpy (m_default_pattern, "%S" PATH_SLASH_STR);
@@ -282,6 +282,13 @@ set_default_pattern (BOOL get_separate_dirs, BOOL do_count)
 	}
     }
     strcat (m_default_pattern, "%A - %T");
+
+    /* m_default_showfile_pattern */
+    m_default_showfile_pattern[0] = '\0';
+    if (get_separate_dirs) {
+	strcpy (m_default_showfile_pattern, "%S" PATH_SLASH_STR);
+    }
+    strcat (m_default_showfile_pattern, "sr_program_%d");
 }
 
 /* This function sets the value of m_output_directory or 
@@ -341,7 +348,8 @@ set_output_directory (char* global_output_directory,
     } else if (*odir_device) {
 	device = odir_device;
     } else {
-	device = cwd_device;
+	/* No device */
+	device = "";
     }
 
     /* Generate the output file pattern. */
