@@ -31,5 +31,13 @@ error_code httplib_parse_sc_header(const char* url, char *header, SR_HTTP_HEADER
 error_code httplib_construct_sc_request(const char *url, const char* proxyurl, char *buffer, char *useragent);
 error_code httplib_construct_page_request(const char *url, BOOL proxyformat, char *buffer);
 error_code httplib_construct_sc_response(SR_HTTP_HEADER *info, char *header, int size, int icy_meta_support);
+error_code inet_get_webpage_alloc(HSOCKET *sock, const char *url,
+					 const char *proxyurl, 
+					 char **buffer, unsigned long *size);
+error_code httplib_sc_connect(HSOCKET *sock, const char *url, 
+				  const char *proxyurl, 
+				  SR_HTTP_HEADER *info, char *useragent, 
+				  char *if_name);
+
 
 #endif //__HTTP_H__
