@@ -14,7 +14,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-  
 /*
  * This is the top level for the streamripper library. The it handles the 
  * connecting the rippers (ripstream, ripshout, riplive) to the sockets 
@@ -44,7 +43,6 @@
 #include "http.h"
 #include "util.h"
 #include "findsep.h"
-#include "inet.h"
 #include "relaylib.h"
 #include "rip_manager.h"
 #include "ripstream.h"
@@ -53,17 +51,9 @@
 #include "compat.h"
 #include "parse.h"
 
-/******************************************************************************
- * Public functions
- *****************************************************************************/
-error_code		rip_manager_start(void (*status_callback)(int message, void *data), RIP_MANAGER_OPTIONS *options);
-void			rip_manager_stop();
-char *			rip_manager_get_error_str(error_code code);
-u_short			rip_mananger_get_relay_port();	
-
 /******************************************************************************
  * Private functions
- ******************************************************************************/
+ *****************************************************************************/
 static void			ripthread(void *bla);
 static error_code		start_relay(int content_type);
 static void			post_status(int status);
@@ -76,7 +66,7 @@ static void			destroy_subsystems();
 
 /******************************************************************************
  * Private Vars
- ******************************************************************************/
+ *****************************************************************************/
 static SR_HTTP_HEADER		m_http_info;
 static HSOCKET			m_sock;
 #if defined (commentout)
@@ -165,12 +155,15 @@ void init_error_strings()
     SET_ERR_STR("SR_ERROR_NOT_SHOUTCAST_STREAM",		0x36);
     SET_ERR_STR("HTTP:407 - Proxy Authentication Required",	0x37);
     SET_ERR_STR("HTTP:403 - Access Forbidden (try changing the UserAgent)", 0x38);
-    SET_ERR_STR("The output directory length is too long", 0x39);
-    SET_ERR_STR("SR_ERROR_PROGRAM_ERROR", 0x3a);
-    SET_ERR_STR("SR_ERROR_TIMEOUT", 0x3b);
-    SET_ERR_STR("SR_ERROR_SELECT_FAILED", 0x3c);
-    SET_ERR_STR("SR_ERROR_RESERVED_WINDOW_EMPTY", 0x3d);
-    SET_ERR_STR("SR_ERROR_CANT_BIND_ON_INTERFACE", 0x3e);
+    SET_ERR_STR("The output directory length is too long",      0x39);
+    SET_ERR_STR("SR_ERROR_PROGRAM_ERROR",                       0x3a);
+    SET_ERR_STR("SR_ERROR_TIMEOUT",                             0x3b);
+    SET_ERR_STR("SR_ERROR_SELECT_FAILED",                       0x3c);
+    SET_ERR_STR("SR_ERROR_RESERVED_WINDOW_EMPTY",               0x3d);
+    SET_ERR_STR("SR_ERROR_CANT_BIND_ON_INTERFACE",              0x3e);
+    SET_ERR_STR("SR_ERROR_NO_OGG_PAGES_FOR_RELAY",              0x3f);
+    SET_ERR_STR("SR_ERROR_CANT_PARSE_PLS",                      0x40);
+    SET_ERR_STR("SR_ERROR_CANT_PARSE_M3U",                      0x41);
 }
 
 char*
@@ -334,7 +327,7 @@ client_relay_header_release (char *ch)
 }
 
 void
-ripthread(void *notused)
+ripthread (void *notused)
 {
     error_code ret;
 
@@ -347,7 +340,7 @@ ripthread(void *notused)
     post_status(RM_STATUS_BUFFERING);
     threadlib_signal_sem(&m_started_sem);
 
-    while(TRUE) {
+    while (TRUE) {
         ret = ripstream_rip();
 
 	/* If the user told us to stop, well, then we bail */
@@ -404,14 +397,13 @@ ripthread(void *notused)
 		// because filelib needs to keep track of it's file counters, and socklib.. umm..
 		// not sure about. no reasdon to i imagine.
 		socklib_close(&m_sock);
+		if (m_ripinfo.ep) {
+		    debug_printf ("Close external\n");
+		    close_external (&m_ripinfo.ep);
+		}
 		relaylib_shutdown();
-		// GCS testing...
 		filelib_shutdown();
 		ripstream_destroy();
-#if defined (commentout)
-		if (m_destroy_func)
-		    m_destroy_func();
-#endif
 		ret = start_ripping();
 		if (ret == SR_SUCCESS)
 		    break;
@@ -460,6 +452,7 @@ rip_manager_stop()
 
     // Kill external process
     if (m_ripinfo.ep) {
+	debug_printf ("Close external\n");
 	close_external (&m_ripinfo.ep);
     }
 
@@ -528,31 +521,21 @@ start_ripping()
     }
 
     /* Connect to the stream */
-    ret = inet_sc_connect(&m_sock, m_options.url, pproxy, &m_http_info, 
+    ret = httplib_sc_connect(&m_sock, m_options.url, pproxy, &m_http_info, 
 			  m_options.useragent, m_options.if_name);
     if (ret != SR_SUCCESS) {
 	goto RETURN_ERR;
     }
 
-#if defined (COMMENTOUT_FOR_OGG)
-    /* GCS 09/10/04 - I wonder if this is worth doing */
-    if (!m_http_info.have_icy_name) {
-	ret = SR_ERROR_NOT_SHOUTCAST_STREAM;
-	goto RETURN_ERR;
-    }
-#endif
-
     /* If the icy_name exists, but is empty, set to a bogus name so 
        that we can create the directory correctly, etc. */
     if (strlen(m_http_info.icy_name) == 0) {
 	strcpy (m_http_info.icy_name, "Streamripper_rips");
     }
 
-    /*
-     * Set the ripinfo struct from the data we now know about the 
+    /* Set the ripinfo struct from the data we now know about the 
      * stream, this info are things like server name, type, 
-     * bitrate etc.. 
-     */
+     * bitrate etc.. */
     memset(&m_ripinfo, 0, sizeof(RIP_MANAGER_INFO));
     m_ripinfo.meta_interval = m_http_info.meta_interval;
     m_ripinfo.bitrate = m_http_info.icy_bitrate;
@@ -620,7 +603,7 @@ start_ripping()
      * the stream we are relaying.. this just sets the header to 
      * something very simulare to what we got from the stream.
      */
-    if (GET_MAKE_RELAY(m_options.flags)) {
+    if (GET_MAKE_RELAY (m_options.flags)) {
 	int new_port = 0;
 	ret = relaylib_init(GET_SEARCH_PORTS(m_options.flags), 
 			    m_options.relay_port, m_options.max_port, 
@@ -689,6 +672,13 @@ rip_manager_start(void (*status_callback)(int message, void *data),
     return SR_SUCCESS;
 }
 
+/* Winamp plugin needs to get content type */
+int
+rip_manager_get_content_type (void)
+{
+    return m_http_info.content_type;
+}
+
 enum OverwriteOpt
 string_to_overwrite_opt (char* str)
 {
