@@ -2,16 +2,20 @@
 #define __RIPLIB_H__
 
 #include "srtypes.h"
+#include "socklib.h"
 
 error_code
-ripstream_init (IO_GET_STREAM *in, 
+ripstream_init (HSOCKET sock, 
+		int have_relay,
+		int timeout, 
 		char *no_meta_name, 
-		int drop_count, 
+		int drop_count,
 		SPLITPOINT_OPTIONS *sp_opt, 
 		int bitrate, 
 		int meta_interval, 
 		int content_type, 
-		BOOL addID3tag);
+		BOOL addID3tag,
+		External_Process* ep);
 error_code ripstream_rip();
 void ripstream_destroy();
 
