@@ -1,5 +1,4 @@
-/* socklib.c - jonclegg@yahoo.com
- * library routines for handling socket stuff
+/* socklib.c
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,7 +14,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -58,37 +56,17 @@
 #endif
 
 
-/*********************************************************************************
- * Public functions
- *********************************************************************************/
-error_code socklib_init();
-error_code socklib_open(HSOCKET *socket_handle, char *host, int port,
-			char *if_name);
-void socklib_close(HSOCKET *socket_handle);
-void socklib_cleanup();
-error_code socklib_read_header(HSOCKET *socket_handle, char *buffer, int size, 
-			       int (*recvall)(HSOCKET *socket_handle, 
-					      char* buffer, int size, 
-					      int timeout));
-int socklib_recvall(HSOCKET *socket_handle, char* buffer, int size,
-		    int timeout);
-int socklib_sendall(HSOCKET *socket_handle, char* buffer, int size);
-error_code socklib_recvall_alloc(HSOCKET *socket_handle, char** buffer, 
-				 unsigned long *size, 
-				 int (*recvall)(HSOCKET *socket_handle, 
-						char* buffer, int size, 
-						int timeout));
-error_code read_interface(char *if_name, uint32_t *addr);
-
-/*********************************************************************************
+/****************************************************************************
  * Private Vars 
- *********************************************************************************/
+ ****************************************************************************/
 static BOOL m_done_init = FALSE; // so we don't init the mutex twice.. arg.
 
-/*
- * Init socket stuff
- */
-error_code socklib_init()
+
+/****************************************************************************
+ * Function definitions
+ ****************************************************************************/
+error_code
+socklib_init()
 {
 #if WIN32
     WORD wVersionRequested;
@@ -111,9 +89,7 @@ error_code socklib_init()
 }
 
 
-/*
- * try to find the local interface to bind to
- */
+/* Try to find the local interface to bind to */
 error_code
 read_interface(char *if_name, uint32_t *addr)
 {
@@ -144,7 +120,6 @@ read_interface(char *if_name, uint32_t *addr)
  * open's a tcp connection to host at port, host can be a dns name or IP,
  * socket_handle gets assigned to the handle for the connection
  */
-
 error_code 
 socklib_open(HSOCKET *socket_handle, char *host, int port, char *if_name)
 {
@@ -291,11 +266,8 @@ socklib_read_header(HSOCKET *socket_handle, char *buffer, int size,
     return SR_SUCCESS;
 }
 
-
-/*
- * Default recv
- */
-int socklib_recvall(HSOCKET *socket_handle, char* buffer, int size, int timeout)
+int
+socklib_recvall (HSOCKET *socket_handle, char* buffer, int size, int timeout)
 {
     int ret = 0, read = 0;
     int sock;
@@ -304,14 +276,13 @@ int socklib_recvall(HSOCKET *socket_handle, char* buffer, int size, int timeout)
     
     sock = socket_handle->s;
     FD_ZERO(&fds);
-    while(size)
-    {
+    while(size) {
 	if (socket_handle->closed)
 	    return SR_ERROR_SOCKET_CLOSED;
 	
-	if (timeout > 0)
-	{
-	    // Wait up to 'timeout' seconds for data on socket to be ready for read
+	if (timeout > 0) {
+	    /* Wait up to 'timeout' seconds for data on socket to be 
+	       ready for read */
 	    FD_SET(sock, &fds);
 	    tv.tv_sec = timeout;
 	    tv.tv_usec = 0;
@@ -321,10 +292,8 @@ int socklib_recvall(HSOCKET *socket_handle, char* buffer, int size, int timeout)
 	    if (ret != 1)
 		return SR_ERROR_TIMEOUT;
 	}
-		
-	//		DEBUG2(("calling recv for %d bytes", size));
+
         ret = recv(socket_handle->s, &buffer[read], size, 0);
-	//		DEBUG2(("recv: %d", ret));
 	debug_printf ("RECV req %5d bytes, got %5d bytes\n", size, ret);
 
         if (ret == SOCKET_ERROR) {
@@ -336,7 +305,7 @@ int socklib_recvall(HSOCKET *socket_handle, char* buffer, int size, int timeout)
 	/* Got zero bytes on blocking read.  For unix this is an 
 	   orderly shutdown. */
 	if (ret == 0) {
-	    debug_printf ("recv recieved zero bytes!\n");
+	    debug_printf ("recv received zero bytes!\n");
 	    break;
 	}
 
@@ -347,12 +316,12 @@ int socklib_recvall(HSOCKET *socket_handle, char* buffer, int size, int timeout)
     return read;
 }
 
-int socklib_sendall(HSOCKET *socket_handle, char* buffer, int size)
+int
+socklib_sendall (HSOCKET *socket_handle, char* buffer, int size)
 {
     int ret = 0, sent = 0;
 
-    while(size)
-    {
+    while(size) {
 	if (socket_handle->closed)
 	    return SR_ERROR_SOCKET_CLOSED;
 
@@ -368,51 +337,4 @@ int socklib_sendall(HSOCKET *socket_handle, char* buffer, int size)
     }
 
     return sent;
-	
-}
-
-error_code
-socklib_recvall_alloc(HSOCKET *socket_handle, char** buffer, 
-		      unsigned long *size, 
-		      int (*recvall)(HSOCKET *socket_handle, char* buffer, 
-				     int size, int timeout))
-{
-    const int CHUNK_SIZE = 8192;
-    int (*myrecv)(HSOCKET *socket_handle, char* buffer, int size, int timeout);
-    int ret;
-    unsigned long mysize = 0;
-    int chunks = 1;
-    char *temp = (char *)malloc(CHUNK_SIZE);
-
-    if (socket_handle->closed)
-	return SR_ERROR_SOCKET_CLOSED;
-
-    if (!size)
-	return SR_ERROR_INVALID_PARAM;
-
-    if (recvall)
-	myrecv = recvall;
-    else
-	myrecv = socklib_recvall;
-
-    while((ret = myrecv(socket_handle, &temp[mysize], (CHUNK_SIZE*chunks)-mysize, 0)) >= 0)
-    {
-	mysize += ret;
-
-	if (ret == 0)
-	    break;
-
-	if ((mysize % CHUNK_SIZE) == 0)
-	{
-	    chunks++;
-	    temp = (char *)realloc(temp, CHUNK_SIZE*chunks);
-	}
-    }
-    if (mysize == 0)
-	return SR_ERROR_RECV_FAILED;
-
-    temp[mysize] = '\0';
-    *size = mysize;
-    *buffer = temp;
-    return SR_SUCCESS;
 }
