@@ -177,11 +177,11 @@ check(va_list ap, int ret, char *str, size_t pmatch_len, regmatch_t *pmatch,
       printf("Exec error, regex: \"%s\", cflags %d, "
 	     "string: \"%s\", eflags %d\n", regex_pattern, cflags,
 	     str, eflags);
-      printf("	got %smatch (regnexec returned %d)\n", ret ? "no " : "", ret);
-      fail = 1;
+      printf("	got %smatch (regexec returned %d)\n", ret ? "no " : "", ret);
+      return 1;
     }
 
-  if (!fail && ret == 0)
+  if (ret == 0)
     {
       unsigned int i;
 
@@ -264,7 +264,7 @@ test_nexec(char *data, size_t len, int eflags, ...)
       exec_tests++;
       m = execute(data, len, elementsof(pmatch), pmatch, final_flags);
       va_start(ap, eflags);
-      fail = check(ap, m, data, elementsof(pmatch), pmatch, final_flags);
+      fail |= check(ap, m, data, elementsof(pmatch), pmatch, final_flags);
       va_end(ap);
 
       /* Same test with a NULL pmatch. */
@@ -317,7 +317,7 @@ test_exec(char *str, int eflags, ...)
 	  exec_tests++;
 	  m = execute(str, len, elementsof(pmatch), pmatch, final_flags);
 	  va_start(ap, eflags);
-	  fail = check(ap, m, str, elementsof(pmatch), pmatch, final_flags);
+	  fail |= check(ap, m, str, elementsof(pmatch), pmatch, final_flags);
 	  va_end(ap);
 
 	  /* Same test with a NULL pmatch. */
@@ -394,13 +394,17 @@ main(int argc, char **argv)
 {
 
   /* Large number of macros in one regexp. */
-  test_comp("[A-Z]\\d\\s?\\d[A-Z]{2}|[A-Z]\\d{2}\\s?\\d[A-Z]{2}|[A-Z]{2}\\d\\s?\\d[A-Z]{2}|[A-Z]{2}\\d{2}\\s?\\d[A-Z]{2}|[A-Z]\\d[A-Z]\\s?\\d[A-Z]{2}|[A-Z]{2}\\d[A-Z]\\s?\\d[A-Z]{2}|[A-Z]{3}\\s?\\d[A-Z]{2}", REG_EXTENDED, 0);
+  test_comp("[A-Z]\\d\\s?\\d[A-Z]{2}|[A-Z]\\d{2}\\s?\\d[A-Z]{2}|[A-Z]{2}\\d"
+	    "\\s?\\d[A-Z]{2}|[A-Z]{2}\\d{2}\\s?\\d[A-Z]{2}|[A-Z]\\d[A-Z]\\s?"
+	    "\\d[A-Z]{2}|[A-Z]{2}\\d[A-Z]\\s?\\d[A-Z]{2}|[A-Z]{3}\\s?\\d[A-Z]"
+	    "{2}", REG_EXTENDED, 0);
 
   test_comp("a{11}(b{2}c){2}", REG_EXTENDED, 0);
   test_comp("a{2}{2}xb+xc*xd?x", REG_EXTENDED, 0);
   test_comp("^!packet [0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3} [0-9]+",
 	    REG_EXTENDED, 0);
-  test_comp("^!pfast [0-9]{1,15} ([0-9]{1,3}\\.){3}[0-9]{1,3}[0-9]{1,5}$", REG_EXTENDED, 0);
+  test_comp("^!pfast [0-9]{1,15} ([0-9]{1,3}\\.){3}[0-9]{1,3}[0-9]{1,5}$",
+	    REG_EXTENDED, 0);
 
 #if 0
   /* Should these match or not? */
@@ -1352,6 +1356,18 @@ main(int argc, char **argv)
   test_comp("\\1foo", REG_EXTENDED, REG_ESUBREG);
   test_comp("\\1foo(bar)", REG_EXTENDED, 0);
 
+  /* Back reference with zero-width assertion. */
+  test_comp("(.)\\1$", REG_EXTENDED, 0);
+  test_exec("foox", 0, REG_NOMATCH);
+  test_exec("foo", 0, REG_OK, 1, 3, 1, 2, END);
+
+  /* Back references together with {}. */
+  test_comp("([0-9]{5})\\1", REG_EXTENDED, 0);
+  test_exec("12345", 0, REG_NOMATCH);
+  test_exec("1234512345", 0, REG_OK, 0, 10, 0, 5, END);
+  test_comp("([0-9]{4})\\1", REG_EXTENDED, 0);
+  test_exec("1234", 0, REG_NOMATCH);
+  test_exec("12341234", 0, REG_OK, 0, 8, 0, 4, END);
 
   /*
    * Test minimal repetitions (non-greedy repetitions)
@@ -1439,7 +1455,6 @@ main(int argc, char **argv)
       test_nexec("foo\000bar", 7, 0, REG_OK, 5, 6, END);
       test_comp("c$", REG_EXTENDED, 0);
       test_exec("abc", 0, REG_OK, 2, 3, END);
-
     }
 #endif /* TRE_MULTIBYTE */
 #endif /* !WIN32 */
